package com.shzg.project.worn.mapper;

import java.util.List;
import com.shzg.project.worn.domain.WornMaterial;

/**
 * 物料Mapper接口
 * 
 * @author shzg
 * @date 2026-03-11
 */
public interface WornMaterialMapper 
{
    /**
     * 查询物料
     * 
     * @param id 物料主键
     * @return 物料
     */
    public WornMaterial selectWornMaterialById(Long id);

    /**
     * 查询物料列表
     * 
     * @param wornMaterial 物料
     * @return 物料集合
     */
    public List<WornMaterial> selectWornMaterialList(WornMaterial wornMaterial);

    /**
     * 新增物料
     * 
     * @param wornMaterial 物料
     * @return 结果
     */
    public int insertWornMaterial(WornMaterial wornMaterial);

    /**
     * 修改物料
     * 
     * @param wornMaterial 物料
     * @return 结果
     */
    public int updateWornMaterial(WornMaterial wornMaterial);

    /**
     * 删除物料
     * 
     * @param id 物料主键
     * @return 结果
     */
    public int deleteWornMaterialById(Long id);

    /**
     * 批量删除物料
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteWornMaterialByIds(Long[] ids);

    /**
     * 查询当前最大物料编码
     */
    String selectMaxMaterialCode();
}
