package com.shzg.project.worn.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.shzg.framework.aspectj.lang.annotation.Log;
import com.shzg.framework.aspectj.lang.enums.BusinessType;
import com.shzg.project.worn.domain.WornMaterial;
import com.shzg.project.worn.service.IWornMaterialService;
import com.shzg.framework.web.controller.BaseController;
import com.shzg.framework.web.domain.AjaxResult;
import com.shzg.common.utils.poi.ExcelUtil;
import com.shzg.framework.web.page.TableDataInfo;

/**
 * 物料Controller
 * 
 * @author shzg
 * @date 2026-03-11
 */
@RestController
@RequestMapping("/worn/material")
public class WornMaterialController extends BaseController
{
    @Autowired
    private IWornMaterialService wornMaterialService;

    /**
     * 查询物料列表
     */
    @PreAuthorize("@ss.hasPermi('worn:material:list')")
    @GetMapping("/list")
    public TableDataInfo list(WornMaterial wornMaterial)
    {
        startPage();
        List<WornMaterial> list = wornMaterialService.selectWornMaterialList(wornMaterial);
        return getDataTable(list);
    }

    /**
     * 导出物料列表
     */
    @PreAuthorize("@ss.hasPermi('worn:material:export')")
    @Log(title = "物料", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, WornMaterial wornMaterial)
    {
        List<WornMaterial> list = wornMaterialService.selectWornMaterialList(wornMaterial);
        ExcelUtil<WornMaterial> util = new ExcelUtil<WornMaterial>(WornMaterial.class);
        util.exportExcel(response, list, "物料数据");
    }

    /**
     * 获取物料详细信息
     */
    @PreAuthorize("@ss.hasPermi('worn:material:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(wornMaterialService.selectWornMaterialById(id));
    }

    /**
     * 新增物料
     */
    @PreAuthorize("@ss.hasPermi('worn:material:add')")
    @Log(title = "物料", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody WornMaterial wornMaterial)
    {
        return toAjax(wornMaterialService.insertWornMaterial(wornMaterial));
    }

    /**
     * 修改物料
     */
    @PreAuthorize("@ss.hasPermi('worn:material:edit')")
    @Log(title = "物料", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody WornMaterial wornMaterial)
    {
        return toAjax(wornMaterialService.updateWornMaterial(wornMaterial));
    }

    /**
     * 删除物料
     */
    @PreAuthorize("@ss.hasPermi('worn:material:remove')")
    @Log(title = "物料", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(wornMaterialService.deleteWornMaterialByIds(ids));
    }
}
